package com.ruoyi.logistics.mapper;

import java.util.List;
import com.ruoyi.logistics.domain.BizFinancialAdjustmentRecord;

/**
 * 调账流水记录Mapper接口
 * 
 * @author RuiJing
 * @date 2026-01-29
 */
public interface BizFinancialAdjustmentRecordMapper 
{
    /**
     * 查询调账流水记录
     * 
     * @param financialAdjustId 调账流水记录主键
     * @return 调账流水记录
     */
    public BizFinancialAdjustmentRecord selectBizFinancialAdjustmentRecordByFinancialAdjustId(Long financialAdjustId);

    /**
     * 查询调账流水记录列表
     * 
     * @param bizFinancialAdjustmentRecord 调账流水记录
     * @return 调账流水记录集合
     */
    public List<BizFinancialAdjustmentRecord> selectBizFinancialAdjustmentRecordList(BizFinancialAdjustmentRecord bizFinancialAdjustmentRecord);

    /**
     * 新增调账流水记录
     * 
     * @param bizFinancialAdjustmentRecord 调账流水记录
     * @return 结果
     */
    public int insertBizFinancialAdjustmentRecord(BizFinancialAdjustmentRecord bizFinancialAdjustmentRecord);

    /**
     * 修改调账流水记录
     * 
     * @param bizFinancialAdjustmentRecord 调账流水记录
     * @return 结果
     */
    public int updateBizFinancialAdjustmentRecord(BizFinancialAdjustmentRecord bizFinancialAdjustmentRecord);

    /**
     * 删除调账流水记录
     * 
     * @param financialAdjustId 调账流水记录主键
     * @return 结果
     */
    public int deleteBizFinancialAdjustmentRecordByFinancialAdjustId(Long financialAdjustId);

    /**
     * 批量删除调账流水记录
     * 
     * @param financialAdjustIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBizFinancialAdjustmentRecordByFinancialAdjustIds(Long[] financialAdjustIds);

    public List<BizFinancialAdjustmentRecord> selectBizFinancialAdjustmentRecordListNoPermission(BizFinancialAdjustmentRecord bizFinancialAdjustmentRecord);
}
